@@ -97,12 +97,12 @@ sub _make_parser
         };
 }
 
-sub _register_db
+sub _register
 {
     my ($url, $section) = @_;
     die qq{Section has not previously been declared, cannot set URL\n}
         unless ( $section );
-    ALPM->register_db( $section => $url );
+    ALPM->register( $section => $url );
     return;
 }
 
@@ -131,12 +131,9 @@ sub new
 
     Carp::croak( "Invalid arguments to ALPM::LoadConfig::new.\n" .
                  'Hash argument must have coderefs as values' )
-        if List::Util::first { ref $_ ne 'CODE' }
-            values %{ $custom_fields_ref };
+        if grep { ref $_ ne 'CODE' } values %{ $custom_fields_ref };
 
-    bless { custom_fields => $custom_fields_ref,
-            auto_register => $params{ 'auto_register' } || 1,
-           }, $class;
+    bless { custom_fields => $custom_fields_ref }, $class;
 }
 
 sub load_file
@@ -154,7 +151,7 @@ sub load_file
       },
       field   => { Server => sub {
                        my $server_url = shift;
-                       _register_db( $server_url, $current_section )
+                       _register( $server_url, $current_section )
                    } },
      };
 
@@ -191,7 +188,7 @@ sub load_file
      # these fields do nothing, for now...
      ( map { ( $_ => \&_null_sub ) } @NULL_OPTS ),
 
-     Server  => sub { _register_db( shift, $current_section ) },
+     Server  => sub { _register( shift, $current_section ) },
      Include => sub {
          die "Cannot have an Include directive in the [options] section\n"
              if ( $current_section eq 'options' );
@@ -216,10 +213,6 @@ sub load_file
 
     _make_parser( $cfg_path, $parser_hooks )->();
 
-    if ( $self->{'auto_register'} ) {
-        ALPM->register( 'local' );
-    }
-
     return;
 }
 
@@ -242,8 +235,7 @@ ALPM::LoadConfig - pacman.conf config file parsing class.
   # Load custom fields as well:
   my $value;
   my %fields = ( 'CustomField' => sub { $value = shift } );
-  my $loader = ALPM::LoadConfig->new( custom_fields => \%fields,
-                                      auto_register => 0 );
+  my $loader = ALPM::LoadConfig->new( custom_fields => \%fields );
   $loader->load_file( '/etc/pacman.conf' );
 
 =head1 DESCRIPTION
@@ -256,8 +248,7 @@ need to use this module directly.
 
 =head2 new
 
- $OBJ = ALPM::LoadConfig->new( [ custom_fields => \%FIELDS_REF,  ]
-                               [ auto_register => $AUTO_REGISTER ] );
+ $OBJ = ALPM::LoadConfig->new( custom_fields => \%FIELDS_REF? );
 
 =over 4
 
@@ -265,7 +256,7 @@ need to use this module directly.
 
 =over 4
 
-=item C<\%FIELDS_REF> (Hash Reference) (Optional)
+=item C<\%FIELDS_REF> B<(Hash Reference) (Optional)>
 
 Keys are field names from the C</etc/pacman.conf> configuration file.
 Values are code references.  When a field is found inside the
@@ -273,18 +264,6 @@ configuration file with the I<exact same> name, then the code
 reference is called, passed the value of the entry as the only
 argument.
 
-=item C<$AUTO_REGISTER> (Optional)
-
-Normally, LoadConfig will automatically call
-C<< ALPM->register_db( 'local' ) >>
-to register the local database after it has read the config file.  If
-you want to override certain ALPM settings immediately after reading
-the config file you will have to turn this feature off.  This is used
-as a boolean value, set it to 0 to disable automatic localdb
-registering.
-
-=back
-
 =back
 
 =head1 METHODS
